==> ejc-procurement-impl-3.0.0-20251215.045513-116-sources.jar: com/ejianc/business/procurement/perform/bean/FileSuperviseEntity.java <==
package com.ejianc.business.procurement.perform.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 监督记录表档案
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_supervise_file")
public class FileSuperviseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="key_link")
    private String keyLink; // 监督环节
    @TableField(value="enabled")
    private Integer enabled; // 启停用
    @TableField(value="content")
    private String content; // 监督内容
    @TableField(value="sec_code")
    private String secCode; // 序号
    @TableField(value="remark")
    private String remark; // 备注
    
    
    

    public String getKeyLink() {
        return keyLink;
    }

    public void setKeyLink(String keyLink) {
        this.keyLink = keyLink;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
    public String getSecCode() {
        return secCode;
    }

    public void setSecCode(String secCode) {
        this.secCode = secCode;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> ejc-procurement-impl-3.0.0-20251216.024558-129-sources.jar: com/ejianc/business/procurement/perform/bean/FileSuperviseEntity.java <==
package com.ejianc.business.procurement.perform.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 监督记录表档案
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_supervise_file")
public class FileSuperviseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="key_link")
    private String keyLink; // 监督环节
    @TableField(value="enabled")
    private Boolean enabled; // 启停用
    @TableField(value="content")
    private String content; // 监督内容
    @TableField(value="sec_code")
    private String secCode; // 序号
    @TableField(value="remark")
    private String remark; // 备注
    
    
    

    public String getKeyLink() {
        return keyLink;
    }

    public void setKeyLink(String keyLink) {
        this.keyLink = keyLink;
    }
    public Boolean getEnabled() {
        return enabled;
    }

    public void setEnabled(Boolean enabled) {
        this.enabled = enabled;
    }
    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
    public String getSecCode() {
        return secCode;
    }

    public void setSecCode(String secCode) {
        this.secCode = secCode;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}
